@@ -3,10 +3,6 @@ package test
 import (
 	"testing"
 
-	"github.com/coredns/coredns/plugin/proxy"
-	"github.com/coredns/coredns/plugin/test"
-	"github.com/coredns/coredns/request"
-
 	"github.com/miekg/dns"
 )
 
@@ -26,9 +22,9 @@ func TestReverseCorefile(t *testing.T) {
 		t.Fatalf("Could not get UDP listening port")
 	}
 
-	p := proxy.NewLookup([]string{udp})
-	state := request.Request{W: &test.ResponseWriter{}, Req: new(dns.Msg)}
-	resp, err := p.Lookup(state, "17.0.0.10.in-addr.arpa.", dns.TypePTR)
+	m := new(dns.Msg)
+	m.SetQuestion("17.0.0.10.in-addr.arpa.", dns.TypePTR)
+	resp, err := dns.Exchange(m, udp)
 	if err != nil {
 		t.Fatal("Expected to receive reply, but didn't")
 	}
